from enum import Enum

class WBTuneFluorescent(Enum):
    SodiumLampMixedLight            = 0x00 # 0
    CoolWhiteFluorescentLamp        = 0x01 # 1
    WarmWhiteFluorescentLamp        = 0x02 # 2
    WhiteFluorescentLamp            = 0x03 # 3
    DayWhiteFluorescentLamp         = 0x04 # 4
    DaylightFluorescentLamp         = 0x05 # 5
    HighColorTemperatureMercuryLamp = 0x06 # 6
