from enum import Enum

# Indicates “AE lock timer – Self-timer – The number of captured frames”
# in the custom menu.
class SelfTimerShootExpose(Enum):
    Frame1 = 0x00
    Frame2 = 0x01
    Frame3 = 0x02
    Frame4 = 0x03
    Frame5 = 0x04
    Frame6 = 0x05
    Frame7 = 0x06
    Frame8 = 0x07
    Frame9 = 0x08
