from enum import Enum

class FunctionButton(Enum):
    SelfTimerSetting                    = 0x00
    ReleaseModeSetting                  = 0x01
    ImageQualityModeAndImageSizeSetting = 0x02
    ISOSensitivitySetting               = 0x03
    WhiteBalanceSetting                 = 0x04
    ADLSetting                          = 0x05
    PlusRAWRecording                    = 0x06
    AutoBracketing                      = 0x07
