from enum import Enum

class LiveViewImageZoomRatio(Enum):
    EntireDisplay   = 0
    Percent25       = 1
    Percent33       = 2
    Percent50       = 3
    Percent67       = 4
    Percent100      = 5
