from enum import Enum

class SceneMode(Enum):
    NightLandscape  = 0x00 # 0
    PartyIndoor     = 0x01 # 1
    BeachSnow       = 0x02 # 2
    Sunset          = 0x03 # 3
    DuskDawn        = 0x04 # 4
    PetPortrait     = 0x05 # 5
    Candlelight     = 0x06 # 6
    Blossom         = 0x07 # 7
    AutumnColors    = 0x08 # 8
    Food            = 0x09 # 9
    Silhouette      = 0x0A # 10
    HighKey         = 0x0B # 11
    LowKey          = 0x0C # 12
