from enum import Enum

class FlashCompensation(Enum):
    Minus18SixthEV = -18
    Minus17SixthEV = -17
    Minus16SixthEV = -16
    Minus15SixthEV = -15
    Minus14SixthEV = -14
    Minus13SixthEV = -13
    Minus12SixthEV = -12
    Minus11SixthEV = -11
    Minus10SixthEV = -10
    Minus9SixthEV  = -9
    Minus8SixthEV  = -8
    Minus7SixthEV  = -7
    Minus6SixthEV  = -6
    Minus5SixthEV  = -5
    Minus4SixthEV  = -4
    Minus3SixthEV  = -3
    Minus2SixthEV  = -2
    Minus1SixthEV  = -1
    ZeroEV         = 0
    Plus1SixthEV   = 1
    Plus2SixthEV   = 2
    Plus3SixthEV   = 3
    Plus4SixthEV   = 4
    Plus5SixthEV   = 5
    Plus6SixthEV   = 6
    Plus7SixthEV   = 7
    Plus8SixthEV   = 8
    Plus9SixthEV   = 9
    Plus10SixthEV  = 10
    Plus11SixthEV  = 11
    Plus12SixthEV  = 12
    Plus13SixthEV  = 13
    Plus14SixthEV  = 14
    Plus15SixthEV  = 15
    Plus16SixthEV  = 16
    Plus17SixthEV  = 17
    Plus18SixthEV  = 18
