from enum import Enum

class ExposureIndicateStatus(Enum):
    Minus60SixthEV  = -60
    Minus59SixthEV  = -59
    Minus58SixthEV  = -58
    Minus57SixthEV  = -57
    Minus56SixthEV  = -56
    Minus55SixthEV  = -55
    Minus54SixthEV  = -54
    Minus53SixthEV  = -53
    Minus52SixthEV  = -52
    Minus51SixthEV  = -51
    Minus50SixthEV  = -50
    Minus49SixthEV  = -49
    Minus48SixthEV  = -48
    Minus47SixthEV  = -47
    Minus46SixthEV  = -46
    Minus45SixthEV  = -45
    Minus44SixthEV  = -44
    Minus43SixthEV  = -43
    Minus42SixthEV  = -42
    Minus41SixthEV  = -41
    Minus40SixthEV  = -40
    Minus39SixthEV  = -39
    Minus38SixthEV  = -38
    Minus37SixthEV  = -37
    Minus36SixthEV  = -36
    Minus35SixthEV  = -35
    Minus34SixthEV  = -34
    Minus33SixthEV  = -33
    Minus32SixthEV  = -32
    Minus31SixthEV  = -31
    Minus30SixthEV  = -30
    Minus29SixthEV  = -29
    Minus28SixthEV  = -28
    Minus27SixthEV  = -27
    Minus26SixthEV  = -26
    Minus25SixthEV  = -25
    Minus24SixthEV  = -24
    Minus23SixthEV  = -23
    Minus22SixthEV  = -22
    Minus21SixthEV  = -21
    Minus20SixthEV  = -20
    Minus19SixthEV  = -19
    Minus18SixthEV  = -18
    Minus17SixthEV  = -17
    Minus16SixthEV  = -16
    Minus15SixthEV  = -15
    Minus14SixthEV  = -14
    Minus13SixthEV  = -13
    Minus12SixthEV  = -12
    Minus11SixthEV  = -11
    Minus10SixthEV  = -10
    Minus9SixthEV   = -9
    Minus8SixthEV   = -8
    Minus7SixthEV   = -7
    Minus6SixthEV   = -6
    Minus5SixthEV   = -5
    Minus4SixthEV   = -4
    Minus3SixthEV   = -3
    Minus2SixthEV   = -2
    Minus1SixthEV   = -1
    ZeroEV          = 0
    Plus1SixthEV    = 1
    Plus2SixthEV    = 2
    Plus3SixthEV    = 3
    Plus4SixthEV    = 4
    Plus5SixthEV    = 5
    Plus6SixthEV    = 6
    Plus7SixthEV    = 7
    Plus8SixthEV    = 8
    Plus9SixthEV    = 9
    Plus10SixthEV   = 10
    Plus11SixthEV   = 11
    Plus12SixthEV   = 12
    Plus13SixthEV   = 13
    Plus14SixthEV   = 14
    Plus15SixthEV   = 15
    Plus16SixthEV   = 16
    Plus17SixthEV   = 17
    Plus18SixthEV   = 18
    Plus19SixthEV   = 19
    Plus20SixthEV   = 20
    Plus21SixthEV   = 21
    Plus22SixthEV   = 22
    Plus23SixthEV   = 23
    Plus24SixthEV   = 24
    Plus25SixthEV   = 25
    Plus26SixthEV   = 26
    Plus27SixthEV   = 27
    Plus28SixthEV   = 28
    Plus29SixthEV   = 29
    Plus30SixthEV   = 30
    Plus31SixthEV   = 31
    Plus32SixthEV   = 32
    Plus33SixthEV   = 33
    Plus34SixthEV   = 34
    Plus35SixthEV   = 35
    Plus36SixthEV   = 36
    Plus37SixthEV   = 37
    Plus38SixthEV   = 38
    Plus39SixthEV   = 39
    Plus40SixthEV   = 40
    Plus41SixthEV   = 41
    Plus42SixthEV   = 42
    Plus43SixthEV   = 43
    Plus44SixthEV   = 44
    Plus45SixthEV   = 45
    Plus46SixthEV   = 46
    Plus47SixthEV   = 47
    Plus48SixthEV   = 48
    Plus49SixthEV   = 49
    Plus50SixthEV   = 50
    Plus51SixthEV   = 51
    Plus52SixthEV   = 52
    Plus53SixthEV   = 53
    Plus54SixthEV   = 54
    Plus55SixthEV   = 55
    Plus56SixthEV   = 56
    Plus57SixthEV   = 57
    Plus58SixthEV   = 58
    Plus59SixthEV   = 59
    Plus60SixthEV   = 60
